Skip site navigation (1)Skip section navigation (2)
Date:      Thu, 5 Jan 2017 05:03:11 +0000 (UTC)
From:      Adrian Chadd <adrian@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-head@freebsd.org
Subject:   svn commit: r311363 - head/sys/net80211
Message-ID:  <201701050503.v0553BbG090626@repo.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: adrian
Date: Thu Jan  5 05:03:11 2017
New Revision: 311363
URL: https://svnweb.freebsd.org/changeset/base/311363

Log:
  [net80211] correct VHT ieee80211com state bits.
  
  * rename the ieee80211com field for vht mcsinfo to be ic_, not iv;
  * add a vht config field, stealing from the spares I left there.
  
  This doesn't change the ABI.

Modified:
  head/sys/net80211/ieee80211_var.h

Modified: head/sys/net80211/ieee80211_var.h
==============================================================================
--- head/sys/net80211/ieee80211_var.h	Thu Jan  5 04:59:37 2017	(r311362)
+++ head/sys/net80211/ieee80211_var.h	Thu Jan  5 05:03:11 2017	(r311363)
@@ -232,8 +232,9 @@ struct ieee80211com {
 	/* VHT information */
 	uint32_t		ic_vhtcaps;	/* VHT capabilities */
 	uint32_t		ic_vhtextcaps;	/* VHT extended capabilities (TODO) */
-	struct ieee80211_vht_mcs_info	iv_vht_mcsinfo; /* Support TX/RX VHT MCS */
-	uint32_t		ic_vht_spare[4];
+	struct ieee80211_vht_mcs_info	ic_vht_mcsinfo; /* Support TX/RX VHT MCS */
+	uint32_t		ic_flags_vht;	/* VHT state flags */
+	uint32_t		ic_vht_spare[3];
 
 	/* optional state for Atheros SuperG protocol extensions */
 	struct ieee80211_superg	*ic_superg;
@@ -651,6 +652,10 @@ MALLOC_DECLARE(M_80211_VAP);
 
 #define	IEEE80211_FVEN_BITS	"\20"
 
+#define	IEEE80211_FVHT_VHT	0x000000001	/* CONF: VHT supported */
+#define	IEEE80211_VFHT_BITS \
+	"\20\1VHT"
+
 int	ic_printf(struct ieee80211com *, const char *, ...) __printflike(2, 3);
 void	ieee80211_ifattach(struct ieee80211com *);
 void	ieee80211_ifdetach(struct ieee80211com *);



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201701050503.v0553BbG090626>